@@ -1,4 +1,4 @@
-from django.conf.urls import include, url
+from django.urls import re_path, include
 
 from wagtail.admin import urls as wagtailadmin_urls
 from wagtail.core import urls as wagtail_urls
@@ -8,8 +8,8 @@ from wagtailautocomplete.urls.public import urlpatterns as autocomplete_public_u
 
 
 urlpatterns = [
-    url(r'^admin/autocomplete/', include(autocomplete_admin_urls)),
-    url(r'^admin/', include(wagtailadmin_urls)),
-    url(r'^autocomplete/', include(autocomplete_public_urls)),
-    url(r'', include(wagtail_urls)),
+    re_path(r'^admin/autocomplete/', include(autocomplete_admin_urls)),
+    re_path(r'^admin/', include(wagtailadmin_urls)),
+    re_path(r'^autocomplete/', include(autocomplete_public_urls)),
+    re_path(r'', include(wagtail_urls)),
 ]
